'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _crypto = require('crypto');

var _crypto2 = _interopRequireDefault(_crypto);

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _ncp = require('ncp');

var _ncp2 = _interopRequireDefault(_ncp);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var copy = _ncp2.default.ncp;

/**
 * Creates a temporary directory and copies the './app folder' inside, and adds a text file with the configuration
 * for the single page app.
 *
 * @param {string} src
 * @param {string} dest
 * @param {{}} options
 * @param callback
 */
function buildApp(src, dest, options, callback) {
    var appArgs = selectAppArgs(options);
    copy(src, dest, function (error) {
        if (error) {
            callback('Error Copying temporary directory: ' + error);
            return;
        }

        _fs2.default.writeFileSync(_path2.default.join(dest, '/nativefier.json'), JSON.stringify(appArgs));

        maybeCopyScripts(options.inject, dest).catch(function (error) {
            console.warn(error);
        }).then(function () {
            changeAppPackageJsonName(dest, appArgs.name, appArgs.targetUrl);
            callback();
        });
    });
}

function maybeCopyScripts(srcs, dest) {
    if (!srcs) {
        return new Promise(function (resolve) {
            resolve();
        });
    }
    var promises = srcs.map(function (src) {
        return new Promise(function (resolve, reject) {
            if (!_fs2.default.existsSync(src)) {
                reject('Error copying injection files: file not found');
                return;
            }

            var destFileName = void 0;
            if (_path2.default.extname(src) === '.js') {
                destFileName = 'inject.js';
            } else if (_path2.default.extname(src) === '.css') {
                destFileName = 'inject.css';
            } else {
                resolve();
                return;
            }

            copy(src, _path2.default.join(dest, 'inject', destFileName), function (error) {
                if (error) {
                    reject('Error Copying injection files: ' + error);
                    return;
                }
                resolve();
            });
        });
    });

    return new Promise(function (resolve, reject) {
        Promise.all(promises).then(function () {
            resolve();
        }).catch(function (error) {
            reject(error);
        });
    });
}

function changeAppPackageJsonName(appPath, name, url) {
    var packageJsonPath = _path2.default.join(appPath, '/package.json');
    var packageJson = JSON.parse(_fs2.default.readFileSync(packageJsonPath));
    packageJson.name = normalizeAppName(name, url);
    _fs2.default.writeFileSync(packageJsonPath, JSON.stringify(packageJson));
}

/**
 * Only picks certain app args to pass to nativefier.json
 * @param options
 * @returns {{name: (*|string), targetUrl: (string|*), counter: *, width: *, height: *, showMenuBar: *, userAgent: *, nativefierVersion: *, insecure: *, disableWebSecurity: *}}
 */
function selectAppArgs(options) {
    return {
        name: options.name,
        targetUrl: options.targetUrl,
        counter: options.counter,
        width: options.width,
        height: options.height,
        minWidth: options.minWidth,
        minHeight: options.minHeight,
        maxWidth: options.maxWidth,
        maxHeight: options.maxHeight,
        showMenuBar: options.showMenuBar,
        fastQuit: options.fastQuit,
        userAgent: options.userAgent,
        nativefierVersion: options.nativefierVersion,
        ignoreCertificate: options.ignoreCertificate,
        insecure: options.insecure,
        flashPluginDir: options.flashPluginDir,
        fullScreen: options.fullScreen,
        hideWindowFrame: options.hideWindowFrame,
        maximize: options.maximize,
        disableContextMenu: options.disableContextMenu,
        disableDevTools: options.disableDevTools
    };
}

function normalizeAppName(appName, url) {
    // use a simple 3 byte random string to prevent collision
    var hash = _crypto2.default.createHash('md5');
    hash.update(url);
    var postFixHash = hash.digest('hex').substring(0, 6);
    var normalized = _lodash2.default.kebabCase(appName.toLowerCase());
    return normalized + '-nativefier-' + postFixHash;
}

exports.default = buildApp;
//# sourceMappingURL=buildApp.js.map
